@@ -10,9 +10,13 @@
    CGLM_INLINE void glm_mat4_print(mat4 matrix, FILE *ostream);
    CGLM_INLINE void glm_mat3_print(mat3 matrix, FILE *ostream);
    CGLM_INLINE void glm_vec4_print(vec4 vec, FILE *ostream);
+   CGLM_INLINE void glm_ivec4_print(ivec4 vec, FILE *ostream);
    CGLM_INLINE void glm_vec3_print(vec3 vec, FILE *ostream);
    CGLM_INLINE void glm_ivec3_print(ivec3 vec, FILE *ostream);
+   CGLM_INLINE void glm_vec2_print(vec2 vec, FILE *ostream);
+   CGLM_INLINE void glm_ivec2_print(ivec2 vec, FILE *ostream);
    CGLM_INLINE void glm_versor_print(versor vec, FILE *ostream);
+   CGLM_INLINE void glm_arch_print(FILE *ostream);
  */
 
 /*
@@ -52,12 +56,20 @@
 #  define CGLM_PRINT_MAX_TO_SHORT 1e5f
 #endif
 
-#ifndef CGLM_PRINT_COLOR
-#  define CGLM_PRINT_COLOR        "\033[36m"
-#endif
-
-#ifndef CGLM_PRINT_COLOR_RESET
-#  define CGLM_PRINT_COLOR_RESET  "\033[0m"
+#ifndef GLM_TESTS_NO_COLORFUL_OUTPUT
+#  ifndef CGLM_PRINT_COLOR
+#    define CGLM_PRINT_COLOR        "\033[36m"
+#  endif
+#  ifndef CGLM_PRINT_COLOR_RESET
+#    define CGLM_PRINT_COLOR_RESET  "\033[0m"
+#  endif
+#else
+#  ifndef CGLM_PRINT_COLOR
+#    define CGLM_PRINT_COLOR
+#  endif
+#  ifndef CGLM_PRINT_COLOR_RESET
+#    define CGLM_PRINT_COLOR_RESET
+#  endif
 #endif
 
 /*!
@@ -67,26 +79,40 @@
  */
 CGLM_INLINE
 void
-glm_arch_print_name(FILE* __restrict ostream) {
+glm_arch_print(FILE* __restrict ostream) {
+  fprintf(ostream, CGLM_PRINT_COLOR "arch: "
 #if defined(CGLM_SIMD_WASM)
-  fprintf(ostream, CGLM_PRINT_COLOR "\ncglm arch: wasm SIMD128"
-    "\n\n" CGLM_PRINT_COLOR_RESET);
+  "wasm SIMD128"
 #elif defined(CGLM_SIMD_x86)
-  fprintf(ostream, CGLM_PRINT_COLOR "\ncglm arch: x86 SSE*" 
-#ifdef __AVX__
-    " AVX"
-#endif
-    "\n\n" CGLM_PRINT_COLOR_RESET);
-#elif defined(CGLM_SIMD_ARM) 
-  fprintf(ostream, CGLM_PRINT_COLOR "\ncglm arch: arm"
-#ifndef __ARM_NEON_FP
+  "x86 SSE* "
+#  ifdef __AVX__
+  " AVX"
+#  endif
+#elif defined(CGLM_SIMD_ARM)
+  "arm"
+#  ifndef __ARM_NEON_FP
     " NEON_FP"
-#endif
-#ifdef CGLM_ARM64
+#  endif
+#  ifdef CGLM_ARM64
     " ARM64"
+#  endif
+#else
+  "uncommon"
 #endif
-    "\n\n" CGLM_PRINT_COLOR_RESET);
-#endif
+  CGLM_PRINT_COLOR_RESET);
+}
+
+/*!
+ * @brief prints current SIMD path in general
+ *
+ * @param[in] ostream    stream to print e.g. stdout, stderr, FILE ...
+ */
+CGLM_INLINE
+void
+glm_arch_print_name(FILE* __restrict ostream) {
+  fprintf(ostream, CGLM_PRINT_COLOR "\ncglm ");
+  glm_arch_print(ostream);
+  fprintf(ostream, "\n\n" CGLM_PRINT_COLOR_RESET);
 }
 
 CGLM_INLINE
@@ -238,6 +264,24 @@ glm_vec4_print(vec4              vec,
 #undef m
 }
 
+CGLM_INLINE
+void
+glm_ivec4_print(ivec4             vec,
+                FILE * __restrict ostream) {
+  int i;
+
+#define m 4
+
+  fprintf(ostream, "Vector (int%d): " CGLM_PRINT_COLOR "\n  (", m);
+
+  for (i = 0; i < m; i++)
+    fprintf(ostream, " % d", vec[i]);
+
+  fprintf(ostream, "  )" CGLM_PRINT_COLOR_RESET "\n\n");
+
+#undef m
+}
+
 CGLM_INLINE
 void
 glm_vec3_print(vec3              vec,
@@ -300,6 +344,24 @@ glm_vec2_print(vec2              vec,
 #undef m
 }
 
+CGLM_INLINE
+void
+glm_ivec2_print(ivec2             vec,
+                FILE * __restrict ostream) {
+  int i;
+
+#define m 2
+
+  fprintf(ostream, "Vector (int%d): " CGLM_PRINT_COLOR "\n  (", m);
+
+  for (i = 0; i < m; i++)
+    fprintf(ostream, " % d", vec[i]);
+
+  fprintf(ostream, "  )" CGLM_PRINT_COLOR_RESET "\n\n");
+
+#undef m
+}
+
 CGLM_INLINE
 void
 glm_versor_print(versor            vec,
@@ -364,11 +426,15 @@ glm_aabb_print(vec3                    bbox[2],
 #define glm_mat3_print(v, s) (void)v; (void)s;
 #define glm_mat2_print(v, s) (void)v; (void)s;
 #define glm_vec4_print(v, s) (void)v; (void)s;
+#define glm_ivec4_print(v, s) (void)v; (void)s;
 #define glm_vec3_print(v, s) (void)v; (void)s;
 #define glm_ivec3_print(v, s) (void)v; (void)s;
 #define glm_vec2_print(v, s) (void)v; (void)s;
+#define glm_ivec2_print(v, s) (void)v; (void)s;
 #define glm_versor_print(v, s) (void)v; (void)s;
 #define glm_aabb_print(v, t, s) (void)v; (void)t; (void)s;
+#define glm_arch_print(s) (void)s;
+#define glm_arch_print_name(s) (void)s;
 
 #endif
 #endif /* cglm_io_h */
