@@ -229,3 +229,9 @@ void
 glmc_quat_rotate_atm(mat4 m, versor q, vec3 pivot) {
   glm_quat_rotate_atm(m, q, pivot);
 }
+
+CGLM_EXPORT
+void
+glmc_quat_make(float * __restrict src, versor dest) {
+  glm_quat_make(src, dest);
+}
