@@ -14,6 +14,24 @@ glmc_vec2(float * __restrict v, vec2 dest) {
   glm_vec2(v, dest);
 }
 
+CGLM_EXPORT
+void
+glmc_vec2_fill(vec2 v, float val) {
+  glm_vec2_fill(v, val);
+}
+
+CGLM_EXPORT
+bool
+glmc_vec2_eq(vec2 v, float val) {
+  return glm_vec2_eq(v, val);
+}
+
+CGLM_EXPORT
+bool
+glmc_vec2_eqv(vec2 a, vec2 b) {
+  return glm_vec2_eqv(a, b);
+}
+
 CGLM_EXPORT
 void
 glmc_vec2_copy(vec2 a, vec2 dest) {
@@ -146,6 +164,43 @@ glmc_vec2_minadd(vec2 a, vec2 b, vec2 dest) {
   glm_vec2_minadd(a, b, dest);
 }
 
+CGLM_EXPORT
+void
+glmc_vec2_subsub(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_subsub(a, b, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec2_addsub(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_addsub(a, b, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec2_mulsub(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_mulsub(a, b, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec2_mulsubs(vec2 a, float s, vec2 dest) {
+  glm_vec2_mulsubs(a, s, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec2_maxsub(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_maxsub(a, b, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec2_minsub(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_minsub(a, b, dest);
+}
+
+
 CGLM_EXPORT
 void
 glmc_vec2_negate_to(vec2 v, vec2 dest) {
@@ -176,6 +231,12 @@ glmc_vec2_rotate(vec2 v, float angle, vec2 dest) {
   glm_vec2_rotate(v, angle, dest);
 }
 
+CGLM_EXPORT
+void
+glmc_vec2_center(vec2 a, vec2 b, vec2 dest) {
+  glm_vec2_center(a, b, dest);
+}
+
 CGLM_EXPORT
 float
 glmc_vec2_distance2(vec2 a, vec2 b) {
