@@ -360,6 +360,34 @@ TEST_DECLARE(glmc_plane_normalize)
 TEST_DECLARE(clamp)
 
 /* euler */
+TEST_DECLARE(glm_euler_xyz_quat_rh) 
+TEST_DECLARE(glm_euler_xzy_quat_rh) 
+TEST_DECLARE(glm_euler_yxz_quat_rh)
+TEST_DECLARE(glm_euler_yzx_quat_rh) 
+TEST_DECLARE(glm_euler_zxy_quat_rh)
+TEST_DECLARE(glm_euler_zyx_quat_rh)
+
+TEST_DECLARE(glm_euler_xyz_quat_lh) 
+TEST_DECLARE(glm_euler_xzy_quat_lh) 
+TEST_DECLARE(glm_euler_yxz_quat_lh)
+TEST_DECLARE(glm_euler_yzx_quat_lh) 
+TEST_DECLARE(glm_euler_zxy_quat_lh)
+TEST_DECLARE(glm_euler_zyx_quat_lh)
+
+TEST_DECLARE(glmc_euler_xyz_quat_rh) 
+TEST_DECLARE(glmc_euler_xzy_quat_rh) 
+TEST_DECLARE(glmc_euler_yxz_quat_rh)
+TEST_DECLARE(glmc_euler_yzx_quat_rh)  
+TEST_DECLARE(glmc_euler_zxy_quat_rh)
+TEST_DECLARE(glmc_euler_zyx_quat_rh)
+
+TEST_DECLARE(glmc_euler_xyz_quat_lh) 
+TEST_DECLARE(glmc_euler_xzy_quat_lh) 
+TEST_DECLARE(glmc_euler_yxz_quat_lh)
+TEST_DECLARE(glmc_euler_yzx_quat_lh)  
+TEST_DECLARE(glmc_euler_zxy_quat_lh)
+TEST_DECLARE(glmc_euler_zyx_quat_lh)
+
 TEST_DECLARE(euler)
 
 /* ray */
@@ -480,11 +508,18 @@ TEST_DECLARE(glm_vec2_muladd)
 TEST_DECLARE(glm_vec2_muladds)
 TEST_DECLARE(glm_vec2_maxadd)
 TEST_DECLARE(glm_vec2_minadd)
+TEST_DECLARE(glm_vec2_subsub)
+TEST_DECLARE(glm_vec2_addsub)
+TEST_DECLARE(glm_vec2_mulsub)
+TEST_DECLARE(glm_vec2_mulsubs)
+TEST_DECLARE(glm_vec2_maxsub)
+TEST_DECLARE(glm_vec2_minsub)
 TEST_DECLARE(glm_vec2_negate_to)
 TEST_DECLARE(glm_vec2_negate)
 TEST_DECLARE(glm_vec2_normalize)
 TEST_DECLARE(glm_vec2_normalize_to)
 TEST_DECLARE(glm_vec2_rotate)
+TEST_DECLARE(glm_vec2_center)
 TEST_DECLARE(glm_vec2_distance2)
 TEST_DECLARE(glm_vec2_distance)
 TEST_DECLARE(glm_vec2_maxv)
@@ -519,11 +554,18 @@ TEST_DECLARE(glmc_vec2_muladd)
 TEST_DECLARE(glmc_vec2_muladds)
 TEST_DECLARE(glmc_vec2_maxadd)
 TEST_DECLARE(glmc_vec2_minadd)
+TEST_DECLARE(glmc_vec2_subsub)
+TEST_DECLARE(glmc_vec2_addsub)
+TEST_DECLARE(glmc_vec2_mulsub)
+TEST_DECLARE(glmc_vec2_mulsubs)
+TEST_DECLARE(glmc_vec2_maxsub)
+TEST_DECLARE(glmc_vec2_minsub)
 TEST_DECLARE(glmc_vec2_negate_to)
 TEST_DECLARE(glmc_vec2_negate)
 TEST_DECLARE(glmc_vec2_normalize)
 TEST_DECLARE(glmc_vec2_normalize_to)
 TEST_DECLARE(glmc_vec2_rotate)
+TEST_DECLARE(glmc_vec2_center)
 TEST_DECLARE(glmc_vec2_distance2)
 TEST_DECLARE(glmc_vec2_distance)
 TEST_DECLARE(glmc_vec2_maxv)
@@ -582,6 +624,12 @@ TEST_DECLARE(glm_vec3_muladd)
 TEST_DECLARE(glm_vec3_muladds)
 TEST_DECLARE(glm_vec3_maxadd)
 TEST_DECLARE(glm_vec3_minadd)
+TEST_DECLARE(glm_vec3_subsub)
+TEST_DECLARE(glm_vec3_addsub)
+TEST_DECLARE(glm_vec3_mulsub)
+TEST_DECLARE(glm_vec3_mulsubs)
+TEST_DECLARE(glm_vec3_maxsub)
+TEST_DECLARE(glm_vec3_minsub)
 TEST_DECLARE(glm_vec3_negate_to)
 TEST_DECLARE(glm_vec3_negate)
 TEST_DECLARE(glm_vec3_normalize)
@@ -655,6 +703,12 @@ TEST_DECLARE(glmc_vec3_muladd)
 TEST_DECLARE(glmc_vec3_muladds)
 TEST_DECLARE(glmc_vec3_maxadd)
 TEST_DECLARE(glmc_vec3_minadd)
+TEST_DECLARE(glmc_vec3_subsub)
+TEST_DECLARE(glmc_vec3_addsub)
+TEST_DECLARE(glmc_vec3_mulsub)
+TEST_DECLARE(glmc_vec3_mulsubs)
+TEST_DECLARE(glmc_vec3_maxsub)
+TEST_DECLARE(glmc_vec3_minsub)
 TEST_DECLARE(glmc_vec3_negate_to)
 TEST_DECLARE(glmc_vec3_negate)
 TEST_DECLARE(glmc_vec3_normalize)
@@ -743,6 +797,12 @@ TEST_DECLARE(glm_vec4_muladd)
 TEST_DECLARE(glm_vec4_muladds)
 TEST_DECLARE(glm_vec4_maxadd)
 TEST_DECLARE(glm_vec4_minadd)
+TEST_DECLARE(glm_vec4_subsub)
+TEST_DECLARE(glm_vec4_addsub)
+TEST_DECLARE(glm_vec4_mulsub)
+TEST_DECLARE(glm_vec4_mulsubs)
+TEST_DECLARE(glm_vec4_maxsub)
+TEST_DECLARE(glm_vec4_minsub)
 TEST_DECLARE(glm_vec4_negate_to)
 TEST_DECLARE(glm_vec4_negate)
 TEST_DECLARE(glm_vec4_normalize)
@@ -809,6 +869,12 @@ TEST_DECLARE(glmc_vec4_muladd)
 TEST_DECLARE(glmc_vec4_muladds)
 TEST_DECLARE(glmc_vec4_maxadd)
 TEST_DECLARE(glmc_vec4_minadd)
+TEST_DECLARE(glmc_vec4_subsub)
+TEST_DECLARE(glmc_vec4_addsub)
+TEST_DECLARE(glmc_vec4_mulsub)
+TEST_DECLARE(glmc_vec4_mulsubs)
+TEST_DECLARE(glmc_vec4_maxsub)
+TEST_DECLARE(glmc_vec4_minsub)
 TEST_DECLARE(glmc_vec4_negate_to)
 TEST_DECLARE(glmc_vec4_negate)
 TEST_DECLARE(glmc_vec4_normalize)
@@ -860,8 +926,27 @@ TEST_DECLARE(glm_ivec2_sub)
 TEST_DECLARE(glm_ivec2_subs)
 TEST_DECLARE(glm_ivec2_mul)
 TEST_DECLARE(glm_ivec2_scale)
+TEST_DECLARE(glm_ivec2_addadd)
+TEST_DECLARE(glm_ivec2_addadds)
+TEST_DECLARE(glm_ivec2_subadd)
+TEST_DECLARE(glm_ivec2_subadds)
+TEST_DECLARE(glm_ivec2_muladd)
+TEST_DECLARE(glm_ivec2_muladds)
+TEST_DECLARE(glm_ivec2_maxadd)
+TEST_DECLARE(glm_ivec2_minadd)
+TEST_DECLARE(glm_ivec2_subsub)
+TEST_DECLARE(glm_ivec2_subsubs)
+TEST_DECLARE(glm_ivec2_addsub)
+TEST_DECLARE(glm_ivec2_addsubs)
+TEST_DECLARE(glm_ivec2_mulsub)
+TEST_DECLARE(glm_ivec2_mulsubs)
+TEST_DECLARE(glm_ivec2_maxsub)
+TEST_DECLARE(glm_ivec2_minsub)
 TEST_DECLARE(glm_ivec2_distance2)
 TEST_DECLARE(glm_ivec2_distance)
+TEST_DECLARE(glm_ivec2_fill)
+TEST_DECLARE(glm_ivec2_eq)
+TEST_DECLARE(glm_ivec2_eqv)
 TEST_DECLARE(glm_ivec2_maxv)
 TEST_DECLARE(glm_ivec2_minv)
 TEST_DECLARE(glm_ivec2_clamp)
@@ -877,8 +962,27 @@ TEST_DECLARE(glmc_ivec2_sub)
 TEST_DECLARE(glmc_ivec2_subs)
 TEST_DECLARE(glmc_ivec2_mul)
 TEST_DECLARE(glmc_ivec2_scale)
+TEST_DECLARE(glmc_ivec2_addadd)
+TEST_DECLARE(glmc_ivec2_addadds)
+TEST_DECLARE(glmc_ivec2_subadd)
+TEST_DECLARE(glmc_ivec2_subadds)
+TEST_DECLARE(glmc_ivec2_muladd)
+TEST_DECLARE(glmc_ivec2_muladds)
+TEST_DECLARE(glmc_ivec2_maxadd)
+TEST_DECLARE(glmc_ivec2_minadd)
+TEST_DECLARE(glmc_ivec2_subsub)
+TEST_DECLARE(glmc_ivec2_subsubs)
+TEST_DECLARE(glmc_ivec2_addsub)
+TEST_DECLARE(glmc_ivec2_addsubs)
+TEST_DECLARE(glmc_ivec2_mulsub)
+TEST_DECLARE(glmc_ivec2_mulsubs)
+TEST_DECLARE(glmc_ivec2_maxsub)
+TEST_DECLARE(glmc_ivec2_minsub)
 TEST_DECLARE(glmc_ivec2_distance2)
 TEST_DECLARE(glmc_ivec2_distance)
+TEST_DECLARE(glmc_ivec2_fill)
+TEST_DECLARE(glmc_ivec2_eq)
+TEST_DECLARE(glmc_ivec2_eqv)
 TEST_DECLARE(glmc_ivec2_maxv)
 TEST_DECLARE(glmc_ivec2_minv)
 TEST_DECLARE(glmc_ivec2_clamp)
@@ -895,8 +999,27 @@ TEST_DECLARE(glm_ivec3_sub)
 TEST_DECLARE(glm_ivec3_subs)
 TEST_DECLARE(glm_ivec3_mul)
 TEST_DECLARE(glm_ivec3_scale)
+TEST_DECLARE(glm_ivec3_addadd)
+TEST_DECLARE(glm_ivec3_addadds)
+TEST_DECLARE(glm_ivec3_subadd)
+TEST_DECLARE(glm_ivec3_subadds)
+TEST_DECLARE(glm_ivec3_muladd)
+TEST_DECLARE(glm_ivec3_muladds)
+TEST_DECLARE(glm_ivec3_maxadd)
+TEST_DECLARE(glm_ivec3_minadd)
+TEST_DECLARE(glm_ivec3_subsub)
+TEST_DECLARE(glm_ivec3_subsubs)
+TEST_DECLARE(glm_ivec3_addsub)
+TEST_DECLARE(glm_ivec3_addsubs)
+TEST_DECLARE(glm_ivec3_mulsub)
+TEST_DECLARE(glm_ivec3_mulsubs)
+TEST_DECLARE(glm_ivec3_maxsub)
+TEST_DECLARE(glm_ivec3_minsub)
 TEST_DECLARE(glm_ivec3_distance2)
 TEST_DECLARE(glm_ivec3_distance)
+TEST_DECLARE(glm_ivec3_fill)
+TEST_DECLARE(glm_ivec3_eq)
+TEST_DECLARE(glm_ivec3_eqv)
 TEST_DECLARE(glm_ivec3_maxv)
 TEST_DECLARE(glm_ivec3_minv)
 TEST_DECLARE(glm_ivec3_clamp)
@@ -911,8 +1034,27 @@ TEST_DECLARE(glmc_ivec3_sub)
 TEST_DECLARE(glmc_ivec3_subs)
 TEST_DECLARE(glmc_ivec3_mul)
 TEST_DECLARE(glmc_ivec3_scale)
+TEST_DECLARE(glmc_ivec3_addadd)
+TEST_DECLARE(glmc_ivec3_addadds)
+TEST_DECLARE(glmc_ivec3_subadd)
+TEST_DECLARE(glmc_ivec3_subadds)
+TEST_DECLARE(glmc_ivec3_muladd)
+TEST_DECLARE(glmc_ivec3_muladds)
+TEST_DECLARE(glmc_ivec3_maxadd)
+TEST_DECLARE(glmc_ivec3_minadd)
+TEST_DECLARE(glmc_ivec3_subsub)
+TEST_DECLARE(glmc_ivec3_subsubs)
+TEST_DECLARE(glmc_ivec3_addsub)
+TEST_DECLARE(glmc_ivec3_addsubs)
+TEST_DECLARE(glmc_ivec3_mulsub)
+TEST_DECLARE(glmc_ivec3_mulsubs)
+TEST_DECLARE(glmc_ivec3_maxsub)
+TEST_DECLARE(glmc_ivec3_minsub)
 TEST_DECLARE(glmc_ivec3_distance2)
 TEST_DECLARE(glmc_ivec3_distance)
+TEST_DECLARE(glmc_ivec3_fill)
+TEST_DECLARE(glmc_ivec3_eq)
+TEST_DECLARE(glmc_ivec3_eqv)
 TEST_DECLARE(glmc_ivec3_maxv)
 TEST_DECLARE(glmc_ivec3_minv)
 TEST_DECLARE(glmc_ivec3_clamp)
@@ -928,6 +1070,22 @@ TEST_DECLARE(glm_ivec4_sub)
 TEST_DECLARE(glm_ivec4_subs)
 TEST_DECLARE(glm_ivec4_mul)
 TEST_DECLARE(glm_ivec4_scale)
+TEST_DECLARE(glm_ivec4_addadd)
+TEST_DECLARE(glm_ivec4_addadds)
+TEST_DECLARE(glm_ivec4_subadd)
+TEST_DECLARE(glm_ivec4_subadds)
+TEST_DECLARE(glm_ivec4_muladd)
+TEST_DECLARE(glm_ivec4_muladds)
+TEST_DECLARE(glm_ivec4_maxadd)
+TEST_DECLARE(glm_ivec4_minadd)
+TEST_DECLARE(glm_ivec4_subsub)
+TEST_DECLARE(glm_ivec4_subsubs)
+TEST_DECLARE(glm_ivec4_addsub)
+TEST_DECLARE(glm_ivec4_addsubs)
+TEST_DECLARE(glm_ivec4_mulsub)
+TEST_DECLARE(glm_ivec4_mulsubs)
+TEST_DECLARE(glm_ivec4_maxsub)
+TEST_DECLARE(glm_ivec4_minsub)
 TEST_DECLARE(glm_ivec4_distance2)
 TEST_DECLARE(glm_ivec4_distance)
 TEST_DECLARE(glm_ivec4_maxv)
@@ -945,6 +1103,22 @@ TEST_DECLARE(glmc_ivec4_sub)
 TEST_DECLARE(glmc_ivec4_subs)
 TEST_DECLARE(glmc_ivec4_mul)
 TEST_DECLARE(glmc_ivec4_scale)
+TEST_DECLARE(glmc_ivec4_addadd)
+TEST_DECLARE(glmc_ivec4_addadds)
+TEST_DECLARE(glmc_ivec4_subadd)
+TEST_DECLARE(glmc_ivec4_subadds)
+TEST_DECLARE(glmc_ivec4_muladd)
+TEST_DECLARE(glmc_ivec4_muladds)
+TEST_DECLARE(glmc_ivec4_maxadd)
+TEST_DECLARE(glmc_ivec4_minadd)
+TEST_DECLARE(glmc_ivec4_subsub)
+TEST_DECLARE(glmc_ivec4_subsubs)
+TEST_DECLARE(glmc_ivec4_addsub)
+TEST_DECLARE(glmc_ivec4_addsubs)
+TEST_DECLARE(glmc_ivec4_mulsub)
+TEST_DECLARE(glmc_ivec4_mulsubs)
+TEST_DECLARE(glmc_ivec4_maxsub)
+TEST_DECLARE(glmc_ivec4_minsub)
 TEST_DECLARE(glmc_ivec4_distance2)
 TEST_DECLARE(glmc_ivec4_distance)
 TEST_DECLARE(glmc_ivec4_maxv)
@@ -1321,8 +1495,36 @@ TEST_LIST {
   
   /* utils */
   TEST_ENTRY(clamp)
-  
+
   /* euler */
+  TEST_ENTRY(glm_euler_xyz_quat_rh) 
+  TEST_ENTRY(glm_euler_xzy_quat_rh) 
+  TEST_ENTRY(glm_euler_yxz_quat_rh)
+  TEST_ENTRY(glm_euler_yzx_quat_rh)  
+  TEST_ENTRY(glm_euler_zxy_quat_rh)
+  TEST_ENTRY(glm_euler_zyx_quat_rh)
+
+  TEST_ENTRY(glm_euler_xyz_quat_lh)
+  TEST_ENTRY(glm_euler_xzy_quat_lh)
+  TEST_ENTRY(glm_euler_yxz_quat_lh)
+  TEST_ENTRY(glm_euler_yzx_quat_lh)
+  TEST_ENTRY(glm_euler_zxy_quat_lh)
+  TEST_ENTRY(glm_euler_zyx_quat_lh)
+
+  TEST_ENTRY(glmc_euler_xyz_quat_rh) 
+  TEST_ENTRY(glmc_euler_xzy_quat_rh) 
+  TEST_ENTRY(glmc_euler_yxz_quat_rh)
+  TEST_ENTRY(glmc_euler_yzx_quat_rh)  
+  TEST_ENTRY(glmc_euler_zxy_quat_rh)
+  TEST_ENTRY(glmc_euler_zyx_quat_rh)
+
+  TEST_ENTRY(glmc_euler_xyz_quat_lh)
+  TEST_ENTRY(glmc_euler_xzy_quat_lh)
+  TEST_ENTRY(glmc_euler_yxz_quat_lh)
+  TEST_ENTRY(glmc_euler_yzx_quat_lh)
+  TEST_ENTRY(glmc_euler_zxy_quat_lh)
+  TEST_ENTRY(glmc_euler_zyx_quat_lh)
+
   TEST_ENTRY(euler)
   
   /* ray */
@@ -1443,11 +1645,18 @@ TEST_LIST {
   TEST_ENTRY(glm_vec2_muladds)
   TEST_ENTRY(glm_vec2_maxadd)
   TEST_ENTRY(glm_vec2_minadd)
+  TEST_ENTRY(glm_vec2_subsub)
+  TEST_ENTRY(glm_vec2_addsub)
+  TEST_ENTRY(glm_vec2_mulsub)
+  TEST_ENTRY(glm_vec2_mulsubs)
+  TEST_ENTRY(glm_vec2_maxsub)
+  TEST_ENTRY(glm_vec2_minsub)
   TEST_ENTRY(glm_vec2_negate_to)
   TEST_ENTRY(glm_vec2_negate)
   TEST_ENTRY(glm_vec2_normalize)
   TEST_ENTRY(glm_vec2_normalize_to)
   TEST_ENTRY(glm_vec2_rotate)
+  TEST_ENTRY(glm_vec2_center)
   TEST_ENTRY(glm_vec2_distance2)
   TEST_ENTRY(glm_vec2_distance)
   TEST_ENTRY(glm_vec2_maxv)
@@ -1481,11 +1690,18 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec2_muladds)
   TEST_ENTRY(glmc_vec2_maxadd)
   TEST_ENTRY(glmc_vec2_minadd)
+  TEST_ENTRY(glmc_vec2_subsub)
+  TEST_ENTRY(glmc_vec2_addsub)
+  TEST_ENTRY(glmc_vec2_mulsub)
+  TEST_ENTRY(glmc_vec2_mulsubs)
+  TEST_ENTRY(glmc_vec2_maxsub)
+  TEST_ENTRY(glmc_vec2_minsub)
   TEST_ENTRY(glmc_vec2_negate_to)
   TEST_ENTRY(glmc_vec2_negate)
   TEST_ENTRY(glmc_vec2_normalize)
   TEST_ENTRY(glmc_vec2_normalize_to)
   TEST_ENTRY(glmc_vec2_rotate)
+  TEST_ENTRY(glmc_vec2_center)
   TEST_ENTRY(glmc_vec2_distance2)
   TEST_ENTRY(glmc_vec2_distance)
   TEST_ENTRY(glmc_vec2_maxv)
@@ -1543,6 +1759,12 @@ TEST_LIST {
   TEST_ENTRY(glm_vec3_muladds)
   TEST_ENTRY(glm_vec3_maxadd)
   TEST_ENTRY(glm_vec3_minadd)
+  TEST_ENTRY(glm_vec3_subsub)
+  TEST_ENTRY(glm_vec3_addsub)
+  TEST_ENTRY(glm_vec3_mulsub)
+  TEST_ENTRY(glm_vec3_mulsubs)
+  TEST_ENTRY(glm_vec3_maxsub)
+  TEST_ENTRY(glm_vec3_minsub)
   TEST_ENTRY(glm_vec3_negate_to)
   TEST_ENTRY(glm_vec3_negate)
   TEST_ENTRY(glm_vec3_normalize)
@@ -1616,6 +1838,12 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec3_muladds)
   TEST_ENTRY(glmc_vec3_maxadd)
   TEST_ENTRY(glmc_vec3_minadd)
+  TEST_ENTRY(glmc_vec3_subsub)
+  TEST_ENTRY(glmc_vec3_addsub)
+  TEST_ENTRY(glmc_vec3_mulsub)
+  TEST_ENTRY(glmc_vec3_mulsubs)
+  TEST_ENTRY(glmc_vec3_maxsub)
+  TEST_ENTRY(glmc_vec3_minsub)
   TEST_ENTRY(glmc_vec3_negate_to)
   TEST_ENTRY(glmc_vec3_negate)
   TEST_ENTRY(glmc_vec3_normalize)
@@ -1704,6 +1932,12 @@ TEST_LIST {
   TEST_ENTRY(glm_vec4_muladds)
   TEST_ENTRY(glm_vec4_maxadd)
   TEST_ENTRY(glm_vec4_minadd)
+  TEST_ENTRY(glm_vec4_subsub)
+  TEST_ENTRY(glm_vec4_addsub)
+  TEST_ENTRY(glm_vec4_mulsub)
+  TEST_ENTRY(glm_vec4_mulsubs)
+  TEST_ENTRY(glm_vec4_maxsub)
+  TEST_ENTRY(glm_vec4_minsub)
   TEST_ENTRY(glm_vec4_negate_to)
   TEST_ENTRY(glm_vec4_negate)
   TEST_ENTRY(glm_vec4_normalize)
@@ -1770,6 +2004,12 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec4_muladds)
   TEST_ENTRY(glmc_vec4_maxadd)
   TEST_ENTRY(glmc_vec4_minadd)
+  TEST_ENTRY(glmc_vec4_subsub)
+  TEST_ENTRY(glmc_vec4_addsub)
+  TEST_ENTRY(glmc_vec4_mulsub)
+  TEST_ENTRY(glmc_vec4_mulsubs)
+  TEST_ENTRY(glmc_vec4_maxsub)
+  TEST_ENTRY(glmc_vec4_minsub)
   TEST_ENTRY(glmc_vec4_negate_to)
   TEST_ENTRY(glmc_vec4_negate)
   TEST_ENTRY(glmc_vec4_normalize)
@@ -1821,8 +2061,27 @@ TEST_LIST {
   TEST_ENTRY(glm_ivec2_subs)
   TEST_ENTRY(glm_ivec2_mul)
   TEST_ENTRY(glm_ivec2_scale)
+  TEST_ENTRY(glm_ivec2_addadd)
+  TEST_ENTRY(glm_ivec2_addadds)
+  TEST_ENTRY(glm_ivec2_subadd)
+  TEST_ENTRY(glm_ivec2_subadds)
+  TEST_ENTRY(glm_ivec2_muladd)
+  TEST_ENTRY(glm_ivec2_muladds)
+  TEST_ENTRY(glm_ivec2_maxadd)
+  TEST_ENTRY(glm_ivec2_minadd)
+  TEST_ENTRY(glm_ivec2_subsub)
+  TEST_ENTRY(glm_ivec2_subsubs)
+  TEST_ENTRY(glm_ivec2_addsub)
+  TEST_ENTRY(glm_ivec2_addsubs)
+  TEST_ENTRY(glm_ivec2_mulsub)
+  TEST_ENTRY(glm_ivec2_mulsubs)
+  TEST_ENTRY(glm_ivec2_maxsub)
+  TEST_ENTRY(glm_ivec2_minsub)
   TEST_ENTRY(glm_ivec2_distance2)
   TEST_ENTRY(glm_ivec2_distance)
+  TEST_ENTRY(glm_ivec2_fill)
+  TEST_ENTRY(glm_ivec2_eq)
+  TEST_ENTRY(glm_ivec2_eqv)
   TEST_ENTRY(glm_ivec2_maxv)
   TEST_ENTRY(glm_ivec2_minv)
   TEST_ENTRY(glm_ivec2_clamp)
@@ -1838,8 +2097,27 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec2_subs)
   TEST_ENTRY(glmc_ivec2_mul)
   TEST_ENTRY(glmc_ivec2_scale)
+  TEST_ENTRY(glmc_ivec2_addadd)
+  TEST_ENTRY(glmc_ivec2_addadds)
+  TEST_ENTRY(glmc_ivec2_subadd)
+  TEST_ENTRY(glmc_ivec2_subadds)
+  TEST_ENTRY(glmc_ivec2_muladd)
+  TEST_ENTRY(glmc_ivec2_muladds)
+  TEST_ENTRY(glmc_ivec2_maxadd)
+  TEST_ENTRY(glmc_ivec2_minadd)
+  TEST_ENTRY(glmc_ivec2_subsub)
+  TEST_ENTRY(glmc_ivec2_subsubs)
+  TEST_ENTRY(glmc_ivec2_addsub)
+  TEST_ENTRY(glmc_ivec2_addsubs)
+  TEST_ENTRY(glmc_ivec2_mulsub)
+  TEST_ENTRY(glmc_ivec2_mulsubs)
+  TEST_ENTRY(glmc_ivec2_maxsub)
+  TEST_ENTRY(glmc_ivec2_minsub)
   TEST_ENTRY(glmc_ivec2_distance2)
   TEST_ENTRY(glmc_ivec2_distance)
+  TEST_ENTRY(glmc_ivec2_fill)
+  TEST_ENTRY(glmc_ivec2_eq)
+  TEST_ENTRY(glmc_ivec2_eqv)
   TEST_ENTRY(glmc_ivec2_maxv)
   TEST_ENTRY(glmc_ivec2_minv)
   TEST_ENTRY(glmc_ivec2_clamp)
@@ -1856,8 +2134,27 @@ TEST_LIST {
   TEST_ENTRY(glm_ivec3_subs)
   TEST_ENTRY(glm_ivec3_mul)
   TEST_ENTRY(glm_ivec3_scale)
+  TEST_ENTRY(glm_ivec3_addadd)
+  TEST_ENTRY(glm_ivec3_addadds)
+  TEST_ENTRY(glm_ivec3_subadd)
+  TEST_ENTRY(glm_ivec3_subadds)
+  TEST_ENTRY(glm_ivec3_muladd)
+  TEST_ENTRY(glm_ivec3_muladds)
+  TEST_ENTRY(glm_ivec3_maxadd)
+  TEST_ENTRY(glm_ivec3_minadd)
+  TEST_ENTRY(glm_ivec3_subsub)
+  TEST_ENTRY(glm_ivec3_subsubs)
+  TEST_ENTRY(glm_ivec3_addsub)
+  TEST_ENTRY(glm_ivec3_addsubs)
+  TEST_ENTRY(glm_ivec3_mulsub)
+  TEST_ENTRY(glm_ivec3_mulsubs)
+  TEST_ENTRY(glm_ivec3_maxsub)
+  TEST_ENTRY(glm_ivec3_minsub)
   TEST_ENTRY(glm_ivec3_distance2)
   TEST_ENTRY(glm_ivec3_distance)
+  TEST_ENTRY(glm_ivec3_fill)
+  TEST_ENTRY(glm_ivec3_eq)
+  TEST_ENTRY(glm_ivec3_eqv)
   TEST_ENTRY(glm_ivec3_maxv)
   TEST_ENTRY(glm_ivec3_minv)
   TEST_ENTRY(glm_ivec3_clamp)
@@ -1872,8 +2169,27 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec3_subs)
   TEST_ENTRY(glmc_ivec3_mul)
   TEST_ENTRY(glmc_ivec3_scale)
+  TEST_ENTRY(glmc_ivec3_addadd)
+  TEST_ENTRY(glmc_ivec3_addadds)
+  TEST_ENTRY(glmc_ivec3_subadd)
+  TEST_ENTRY(glmc_ivec3_subadds)
+  TEST_ENTRY(glmc_ivec3_muladd)
+  TEST_ENTRY(glmc_ivec3_muladds)
+  TEST_ENTRY(glmc_ivec3_maxadd)
+  TEST_ENTRY(glmc_ivec3_minadd)
+  TEST_ENTRY(glmc_ivec3_subsub)
+  TEST_ENTRY(glmc_ivec3_subsubs)
+  TEST_ENTRY(glmc_ivec3_addsub)
+  TEST_ENTRY(glmc_ivec3_addsubs)
+  TEST_ENTRY(glmc_ivec3_mulsub)
+  TEST_ENTRY(glmc_ivec3_mulsubs)
+  TEST_ENTRY(glmc_ivec3_maxsub)
+  TEST_ENTRY(glmc_ivec3_minsub)
   TEST_ENTRY(glmc_ivec3_distance2)
   TEST_ENTRY(glmc_ivec3_distance)
+  TEST_ENTRY(glmc_ivec3_fill)
+  TEST_ENTRY(glmc_ivec3_eq)
+  TEST_ENTRY(glmc_ivec3_eqv)
   TEST_ENTRY(glmc_ivec3_maxv)
   TEST_ENTRY(glmc_ivec3_minv)
   TEST_ENTRY(glmc_ivec3_clamp)
@@ -1889,6 +2205,22 @@ TEST_LIST {
   TEST_ENTRY(glm_ivec4_subs)
   TEST_ENTRY(glm_ivec4_mul)
   TEST_ENTRY(glm_ivec4_scale)
+  TEST_ENTRY(glm_ivec4_addadd)
+  TEST_ENTRY(glm_ivec4_addadds)
+  TEST_ENTRY(glm_ivec4_subadd)
+  TEST_ENTRY(glm_ivec4_subadds)
+  TEST_ENTRY(glm_ivec4_muladd)
+  TEST_ENTRY(glm_ivec4_muladds)
+  TEST_ENTRY(glm_ivec4_maxadd)
+  TEST_ENTRY(glm_ivec4_minadd)
+  TEST_ENTRY(glm_ivec4_subsub)
+  TEST_ENTRY(glm_ivec4_subsubs)
+  TEST_ENTRY(glm_ivec4_addsub)
+  TEST_ENTRY(glm_ivec4_addsubs)
+  TEST_ENTRY(glm_ivec4_mulsub)
+  TEST_ENTRY(glm_ivec4_mulsubs)
+  TEST_ENTRY(glm_ivec4_maxsub)
+  TEST_ENTRY(glm_ivec4_minsub)
   TEST_ENTRY(glm_ivec4_distance2)
   TEST_ENTRY(glm_ivec4_distance)
   TEST_ENTRY(glm_ivec4_maxv)
@@ -1905,6 +2237,22 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec4_subs)
   TEST_ENTRY(glmc_ivec4_mul)
   TEST_ENTRY(glmc_ivec4_scale)
+  TEST_ENTRY(glmc_ivec4_addadd)
+  TEST_ENTRY(glmc_ivec4_addadds)
+  TEST_ENTRY(glmc_ivec4_subadd)
+  TEST_ENTRY(glmc_ivec4_subadds)
+  TEST_ENTRY(glmc_ivec4_muladd)
+  TEST_ENTRY(glmc_ivec4_muladds)
+  TEST_ENTRY(glmc_ivec4_maxadd)
+  TEST_ENTRY(glmc_ivec4_minadd)
+  TEST_ENTRY(glmc_ivec4_subsub)
+  TEST_ENTRY(glmc_ivec4_subsubs)
+  TEST_ENTRY(glmc_ivec4_addsub)
+  TEST_ENTRY(glmc_ivec4_addsubs)
+  TEST_ENTRY(glmc_ivec4_mulsub)
+  TEST_ENTRY(glmc_ivec4_mulsubs)
+  TEST_ENTRY(glmc_ivec4_maxsub)
+  TEST_ENTRY(glmc_ivec4_minsub)
   TEST_ENTRY(glmc_ivec4_distance2)
   TEST_ENTRY(glmc_ivec4_distance)
   TEST_ENTRY(glmc_ivec4_maxv)
